# fin_balance_std 一般工商业资产负债表

**fin_balance_std (order_book_id, items, count, filter, offset)**
获取一般行业资产负债数据.
注：该表包含所有A股品种资产负债数据，包括银行、证券、保险类字段。可理解为合并财务报表。若使用需要获取金融类的特有字段，可以直接查询金融类专用财务报表（银行、证券、保险）。 

| 参数 | 类型 | 说明 |
| :--------------------: | :----------------: | --------------------------------- |
|order_book_id | str or str list | 合约代码，必填项 |
|[items](#一般工商业资产负债表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值:list类型


```py
#获取'归属于母公司所有者权益合计'财务字段。
TEquityAttrP = fin_balance_std('SZ000001', 'TEquityAttrP', 10, 0, 0)
#判断获取数据长度是否足够。
if len(TEquityAttrP)<10:
    print("财务数据获取不足，请补充下载")
else:
    print(TEquityAttrP)
```

```py
#多维度财务获取。
#获得'600007'和'600008'品种的'归属于母公司所有者权益合计'和'所有者权益合计'财务字段
df=fin_balance_std(['sh600007', 'SH600008'], ['TEquityAttrP', 'TShEquity'], 1, 0, 0)
```
----

# fin_balance_zq 证券业资产负债表 

**fin_balance_zq (order_book_id, items, count, filter, offset)**

获取披露的证券行业资产负债数据。

| 参数 | 类型 | 说明 |
| :------------------------------------: | :-------------: | -------------------------------------------- |
|order_book_id  | str or str list | 合约代码，必填项 |
| [items](#证券业资产负债表)  | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值:list 类型


# fin_balance_bx保险业资产负债表 

**fin_balance_bx (order_book_id, items, count, filter, offset)**
获取保险行业披露的资产负债数据。

| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#保险业资产负债表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值:list类型

----

# fin_balance_yh 银行业资产负债表

fin_balance_yh (order_book_id, items, count, filter, offset)
获取银行业披露的资产负债数据。

| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#银行业资产负债表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

-----

# fin_profit_std 一般工商业利润分配表

**fin_profit_std (order_book_id, items, count, filter, offset)**

一般工商业利润分配表

注：该表包含所有A股品种资产负债数据，包括银行、证券、保险类字段。可理解为合并财务报表。若使用需要获取金融类的特有字段，可以直接查询金融类专用财务报表（银行、证券、保险）。

| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#一般工商业利润分配表)| str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

```py
#获取'营业总收入'财务字段数据
tRevenue = fin_profit_std('SH600007', 'tRevenue', 1, 0, 0)
```
----

# fin_profit_zq 证券业资产利润分配表

**fin_profit_zq (order_book_id, items, count, filter, offset)**
证券业利润分配表


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#证券业资产利润分配表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型



# fin_profit_bx 保险业利润分配表

**fin_profit_bx (order_book_id, items, count, filter, offset)**
保险业利润分配表

| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#保险业利润分配表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

# fin_profit_yh 银行业利润分配表

fin_profit_yh (order_book_id, items, count, filter, offset)
银行业利润分配表


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#银行业利润分配表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

---

# fin_cashflow_std 一般工商业现金流量表

**fin_cashflow_std (order_book_id, items, count, filter, offset)**
一般工商业现金流量表

参数

| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#一般工商业现金流量表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型


```py
#获取'经营活动现金流出小计'财务字段。
COutfOperateA = fin_cashflow_std('SH600007', 'COutfOperateA', 1, 0, 0)
```

------

# fin_cashflow_zq 证券行业现金流量表

**fin_cashflow_zq (order_book_id, items, count, filter, offset)**
证券行业现金流量表

|参数| 类型 | 说明  |
| :---------: | :--: | ----------- |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#证券行业现金流量表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

----

# fin_cashflow_bx 保险业现金流量表

fin_cashflow_bx (order_book_id, items, count, filter, offset)
保险业现金流量表


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#保险业现金流量表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

--------

# fin_cashflow_yh 银行业现金流量表

fin_cashflow_yh (order_book_id, items, count, filter, offset)
银行业现金流量表


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#银行业现金流量表) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

# fin_indicator 衍生数据表

**fin_indicator (order_book_id, items, count, filter, offset)**
财务衍生数据字段。


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#衍生数据) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

```py
#获取衍生数据'每股收益'的财务数据
EPS = fin_indicator('SH600007', 'EPS', 1, 0, 0)
```

-------

# fin_com_holder 持股股东数

fin_com_holder (order_book_id, items, count, filter, offset)
持股股东户数


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#持股股东户数) | str or str list | 数据项名称，必填项  |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

```py
#得到'SH600007'品种的持股股东户数
shNum = fin_com_holder('SH600007', 'shNum', 1, 0, 0)
```

# fin_com_share 股本结构表

fin_com_share (order_book_id, items, count, offset)
股本结构表

| 参数 | 类型 | 说明|
| :----------------------------------------------------------: | :--: | --------------------------------------- |
|order_book_id | str or str list | 合约代码，必填项|
| [股本结构](#股本结构) | str or str list | 数据项名称，必填项 |
|count | int | 获取的历史记录条数，默认为1 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值：list类型

```py
#获取总股本
totalShares = fin_com_share('SH600007', 'totalShares', 1, 0)
```
------

# fin_com_swhy2014 申万行业分类

**fin_com_swhy2014 (order_book_id, items)**
申万行业分类，该表只提供最新的品种分类信息数据。


| 参数 | 类型 | 说明  |
| ------------------------------------------------------------ | ---- | ------------------ |
| order_book_id| str | 合约代码，必填项  |
| [items](#申万行业代码2014版) | str | 数据项名称，必填项 |

返回值:数据项对应值 

范例

```py
#获取该品种的三级分类名称
industryName = fin_com_swhy2014('SH600007', 'industryName3')
```

# fin_stock_information 公司IPO信息表

fin_stock_information (order_book_id, items)
公司IPO信息表，公司上市时的信息。

| 参数 | 类型 | 说明  |
| ------------------------------------------------------------ | ---- | ------------------ |
| order_book_id| str | 合约代码，必填项  |
| [items](#ipo信息) | str | 数据项名称，必填项 |

返回值:数据项对应值 


```py
#上市日期
listDate = fin_stock_information('SH600007', 'listDate')
```


# fin_holder_top10 公司十大股东

fin_holder_top10 (order_book_id, items, sort, count, filter, offset)
公司十大股东

| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#公司十大股东) | str or str list | 数据项名称，必填项  |
| sort | int | 排名 |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值:list

```py
#获得排名第二的股东名称
holder_top = fin_holder_top10('SH600007', 'shName', 2, 1, 0, 0)
```

<br>

# fin_tradableshare_top10 公司十大流通股东

fin_tradableshare_top10 (order_book_id, items, sort, count, filter, offset)
公司十大流通股东


| 参数 | 类型 | 说明 |
| :----------------------------------------------------------: | :--: | ------------------------------------------------------------ |
|order_book_id | str or str list | 合约代码，必填项 |
| [items](#公司十大流通股东) | str or str list | 数据项名称，必填项  |
| sort | int | 排名 |
|count | int | 获取的历史记录条数，默认为1 |
|filter| int | 是否过滤 0则表示不做过滤, 为1过滤第一季度, 为2表示第二季度中报, 为3表示第三季度, 为4表示第四季度年报 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值:list 


# fin_limited_list 股改限售解禁明细

fin_limited_list (order_book_id, items, count, offset)
股改限售解禁明细


| 参数 | 类型 | 说明|
| :----------------------------------------------------------: | :--: | --------------------------------------- |
|order_book_id | list | 合约代码，必填项|
| [items](#限售解禁明细) | list | 数据项名称，必填项 |
|count | int | 获取的历史记录条数，默认为1 |
|offset| int | 为偏移数量为整数往前偏移, 为负数向后偏移 |

返回值 ：list类型


# 一般工商业资产负债表

三大基本报表中，一般工商业的报表包含，银行、证券、保险类的股票品种。单独提供的银行、证券、保险类的报表字段具有自所属分类的独有字段。一般情况下优先使用一般工商业中的财报字段即可。

```py
#获取'归属于母公司所有者权益合计'财务字段。
TEquityAttrP = fin_balance_std('SZ000001','TEquityAttrP',10,0,0)
#判断获取数据长度是否足够。
if len(TEquityAttrP)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(TEquityAttrP)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]，保险：[1]，证券：[2]，银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	cashCEquiv	|	货币资金	|
|	tradingFA	|	交易性金融资产	|
|	NotesReceiv	|	应收票据	|
|	AR	|	应收账款	|
|	prepayment	|	预付款项	|
|	intReceiv	|	应收利息	|
|	divReceiv	|	应收股利	|
|	othReceiv	|	其他应收款	|
|	inventories	|	存货	|
|	assetsHeldForSale	|	划分为持有待售的资产	|
|	NCAWithin1Y	|	一年内到期的非流动资产	|
|	othCA	|	其他流动资产	|
|	TCA	|	流动资产合计	|
|	availForSaleFa	|	可供出售金融资产	|
|	htmInvest	|	持有至到期投资	|
|	LTReceive	|	长期应收款	|
|	LTEquityInvest	|	长期股权投资	|
|	investRealEstate	|	投资性房地产	|
|	fixedAssets	|	固定资产	|
|	CIP	|	在建工程	|
|	constMaterials	|	工程物资	|
|	fixedAssetsDisp	|	固定资产清理	|
|	producBiolAssets	|	生产性生物资产	|
|	oilAndGasAssets	|	油气资产	|
|	intanAssets	|	无形资产	|
|	RD	|	开发支出	|
|	goodwill	|	商誉	|
|	LTAmorExp	|	长期待摊费用	|
|	deferTaxAssets	|	递延所得税资产	|
|	othNCA	|	其他非流动资产	|
|	TNCA	|	非流动资产合计	|
|	TAssets	|	资产总计	|
|	STBorr	|	短期借款	|
|	tradingFL	|	交易性金融负债	|
|	NotesPayable	|	应付票据	|
|	AP	|	应付账款	|
|	advanceReceipts	|	预收款项	|
|	payrollPayable	|	应付职工薪酬	|
|	taxesPayable	|	应交税费	|
|	intPayable	|	应付利息	|
|	divPayable	|	应付股利	|
|	othPayable	|	其他应付款	|
|	liabHeldForSale	|	划分为持有待售的负债	|
|	NCLWithin1Y	|	一年内到期的非流动负债	|
|	accruedExp	|	预提费用	|
|	othCL	|	其他流动负债	|
|	TCL	|	流动负债合计	|
|	LTBorr	|	长期借款	|
|	bondPayable	|	应付债券	|
|	LTPayable	|	长期应付款	|
|	LTPayrollPayable	|	长期应付职工薪酬	|
|	specificPayables	|	专项应付款	|
|	estimatedLiab	|	预计负债	|
|	deferRevenue	|	递延收益	|
|	deferTaxLiab	|	递延所得税负债	|
|	othNCL	|	其他非流动负债	|
|	TNCL	|	非流动负债合计	|
|	TLiab	|	负债合计	|
|	paidInCapital	|	实收资本(或股本)	|
|	othEquityInstr	|	其他权益工具	|
|	capitalReser	|	资本公积	|
|	othCompreIncome	|	其他综合收益	|
|	specialReser	|	专项储备	|
|	surplusReser	|	盈余公积	|
|	ordinRiskReser	|	一般风险准备	|
|	retainedEarnings	|	未分配利润	|
|	forexDiffer	|	外币报表折算差额	|
|	TEquityAttrP	|	归属于母公司所有者权益合计	|
|	minorityInt	|	少数股东权益	|
|	TShEquity	|	所有者权益合计	|
|	TLiabEquity	|	负债和所有者权益总计	|


#  一般工商业利润分配表


```py
#获取'营业总收入'财务字段数据
tRevenue = fin_profit_std('SH600007','tRevenue',1,0,0)
print(tRevenue)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	tRevenue	|	营业总收入	|
|	revenue	|	营业收入	|
|	intIncome	|	利息收入	|
|	intExp	|	利息支出	|
|	premEarned	|	已赚保费	|
|	commisIncome	|	手续费及佣金收入	|
|	commisExp	|	手续费及佣金支出	|
|	TCogs	|	营业总成本	|
|	COGS	|	营业成本	|
|	premRefund	|	退保金	|
|	NCompensPayout	|	赔付支出净额	|
|	reserInsurContr	|	提取保险合同准备金净额	|
|	policyDivPayt	|	保单红利支出	|
|	reinsurExp	|	分保费用	|
|	bizTaxSurchg	|	营业税金及附加	|
|	sellExp	|	销售费用	|
|	adminExp	|	管理费用	|
|	finanExp	|	财务费用	|
|	assetsImpairLoss	|	资产减值损失	|
|	fValueChgGain	|	公允价值变动收益	|
|	investIncome	|	投资收益	|
|	AJInvestIncome	|	其中:对联营企业和合营企业的投资收益	|
|	forexGain	|	汇兑收益	|
|	operateProfit	|	营业利润	|
|	NoperateIncome	|	营业外收入	|
|	NoperateExp	|	营业外支出	|
|	NCADisploss	|	非流动资产处置损失	|
|	TProfit	|	利润总额	|
|	incomeTax	|	所得税费用	|
|	NIncome	|	净利润	|
|	NIncomeAttrP	|	归属于母公司所有者的净利润	|
|	minorityGain	|	少数股东损益	|
|	basicEPS	|	基本每股收益	|
|	dilutedEPS	|	稀释每股收益	|
|	othComprIncome	|	其他综合收益	|
|	TComprIncome	|	综合收益总额	|
|	comprIncAttrP	|	归属于母公司所有者的综合收益总额	|
|	comprIncAttrMS	|	归属于少数股东的综合收益总额	|


# 一般工商业现金流量表


```py
#获取'经营活动现金流出小计'财务字段。
COutfOperateA = fin_cashflow_std('SH600007','COutfOperateA',1,0,0)
print(COutfOperateA)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	CFrSaleGS	|	销售商品、提供劳务收到的现金	|
|	refundOfTax	|	收到的税费返还	|
|	CFrOthOperateA	|	收到其他与经营活动有关的现金	|
|	CInfFrOperateA	|	经营活动现金流入小计	|
|	CPaidGS	|	购买商品、接受劳务支付的现金	|
|	CPaidToForEmpl	|	支付给职工以及为职工支付的现金	|
|	CPaidForTaxes	|	支付的各项税费	|
|	CPaidForOthOpA	|	支付其他与经营活动有关的现金	|
|	COutfOperateA	|	经营活动现金流出小计	|
|	NCFOperateA	|	经营活动产生的现金流量净额	|
|	procSellInvest	|	收回投资收到的现金	|
|	gainInvest	|	取得投资收益收到的现金	|
|	dispFixAssetsOth	|	处置固定资产、无形资产和其他长期资产收回的现金净额	|
|	NDispSubsOthBizC	|	处置子公司及其他营业单位收到的现金净额	|
|	CFrOthInvestA	|	收到其他与投资活动有关的现金	|
|	CInfFrInvestA	|	投资活动现金流入小计	|
|	purFixAssetsOth	|	购建固定资产、无形资产和其他长期资产支付的现金	|
|	CPaidInvest	|	投资支付的现金	|
|	NCPaidAcquis	|	取得子公司及其他营业单位支付的现金净额	|
|	CPaidOthInvestA	|	支付其他与投资活动有关的现金	|
|	COutfFrInvestA	|	投资活动现金流出小计	|
|	NCFFrInvestA	|	投资活动产生的现金流量净额	|
|	CFrCapContr	|	吸收投资收到的现金	|
|	CFrMinoSSubs	|	其中:子公司吸收少数股东投资收到的现金	|
|	CFrBorr	|	取得借款收到的现金	|
|	CFrIssueBond	|	发行债券收到的现金	|
|	CFrOthFinanA	|	收到其他与筹资活动有关的现金	|
|	CInfFrFinanA	|	筹资活动现金流入小计	|
|	CPaidForDebts	|	偿还债务支付的现金	|
|	CPaidDivProfInt	|	分配股利、利润或偿付利息支付的现金	|
|	divProfSubsMinoS	|	其中:子公司支付给少数股东的股利、利润	|
|	CPaidOthFinanA	|	支付其他与筹资活动有关的现金	|
|	COutfFrFinanA	|	筹资活动现金流出小计	|
|	NCFFrFinanA	|	筹资活动产生的现金流量净额	|
|	forexEffects	|	汇率变动对现金及现金等价物的影响	|
|	NChangeInCash	|	现金及现金等价物净增加额	|
|	NCEBegBal	|	加:期初现金及现金等价物余额	|
|	NCEEndBal	|	期末现金及现金等价物余额	|


# 证券业资产负债表

```py
#获取'归属于母公司所有者权益合计'财务字段。
TEquityAttrP = fin_balance_bx('SH600837','TEquityAttrP',10,0,0)
#判断获取数据长度是否足够。
if len(TEquityAttrP)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(TEquityAttrP)
```

|名称 | 描述 |
|:---------:|:----------:|
|	名称	|	描述	|
|	secID	|	市场+股票代码，如SH600837	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	cashCEquiv	|	货币资金	|
|	clientDepos	|	其中:客户资金存款	|
|	settProv	|	结算备付金	|
|	clientProv	|	其中:客户备付金	|
|	loanToOthBankFi	|	拆出资金	|
|	tradingFA	|	交易性金融资产	|
|	intReceiv	|	应收利息	|
|	purResaleFa	|	买入返售金融资产	|
|	availForSaleFa	|	可供出售金融资产	|
|	htmInvest	|	持有至到期投资	|
|	LTEquityInvest	|	长期股权投资	|
|	investRealEstate	|	投资性房地产	|
|	fixedAssets	|	固定资产	|
|	intanAssets	|	无形资产	|
|	transacSeatFee	|	其中:交易席位费	|
|	deferTaxAssets	|	递延所得税资产	|
|	derivAssets	|	衍生金融资产	|
|	refundDepos	|	存出保证金	|
|	TAssets	|	资产总计	|
|	STBorr	|	短期借款	|
|	pledgeBorr	|	其中:质押借款	|
|	loanFrOthBankFi	|	拆入资金	|
|	tradingFL	|	交易性金融负债	|
|	soldForRepurFa	|	卖出回购金融资产款	|
|	payrollPayable	|	应付职工薪酬	|
|	taxesPayable	|	应交税费	|
|	intPayable	|	应付利息	|
|	fundsSecTradAgen	|	代理买卖证券款	|
|	fundsSecUndwAgen	|	代理承销证券款	|
|	LTBorr	|	长期借款	|
|	bondPayable	|	应付债券	|
|	estimatedLiab	|	预计负债	|
|	deferTaxLiab	|	递延所得税负债	|
|	derivLiab	|	衍生金融负债	|
|	othLiab	|	其他负债	|
|	TLiab	|	负债合计	|
|	paidInCapital	|	实收资本(或股本)	|
|	capitalReser	|	资本公积	|
|	treasuryShare	|	减:库存股	|
|	surplusReser	|	盈余公积	|
|	ordinRiskReser	|	一般风险准备	|
|	transacRiskReser	|	交易风险准备	|
|	retainedEarnings	|	未分配利润	|
|	forexDiffer	|	外币报表折算差额	|
|	TEquityAttrP	|	归属于母公司所有者权益合计	|
|	minorityInt	|	少数股东权益	|
|	TShEquity	|	所有者权益合计	|
|	TLiabEquity	|	负债和所有者权益总计	|
|	othEquityInstr	|	其他权益工具	|
|	othCompreIncome	|	其他综合收益	|


# 证券业利润分配表


```py
revenue = fin_profit_zq('SH600837','revenue',10,0,0)
#判断获取数据长度是否足够。
if len(revenue)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(revenue)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	revenue	|	营业收入	|
|	NIntIncome	|	利息净收入	|
|	NCommisIncome	|	手续费及佣金净收入	|
|	NSecTaIncome	|	代理买卖证券业务净收入	|
|	NUndwrtSecIncome	|	证券承销业务净收入	|
|	NTrustIncome	|	委托客户资产管理业务净收入	|
|	othOperRev	|	其他业务收入	|
|	COGS	|	营业支出	|
|	bizTaxSurchg	|	营业税金及附加	|
|	genlAdminExp	|	业务及管理费	|
|	assetsImpairLoss	|	资产减值损失	|
|	othOperCosts	|	其他业务成本	|
|	fValueChgGain	|	公允价值变动收益	|
|	investIncome	|	投资收益	|
|	AJInvestIncome	|	其中:对联营企业和合营企业的投资收益	|
|	forexGain	|	汇兑收益	|
|	operateProfit	|	营业利润	|
|	NoperateIncome	|	营业外收入	|
|	NoperateExp	|	营业外支出	|
|	TProfit	|	利润总额	|
|	incomeTax	|	所得税费用	|
|	NIncome	|	净利润	|
|	NIncomeAttrP	|	归属于母公司所有者的净利润	|
|	minorityGain	|	少数股东损益	|
|	basicEPS	|	基本每股收益	|
|	dilutedEPS	|	稀释每股收益	|
|	othComprIncome	|	其他综合收益	|
|	TComprIncome	|	综合收益总额	|
|	comprIncAttrP	|	归属于母公司所有者的综合收益总额	|
|	comprIncAttrMS	|	归属于少数股东的综合收益总额	|


# 证券业现金流量表

```py
#获取'归属于母公司所有者权益合计'财务字段。
CInfFrOperateA = fin_cashflow_bx('SH600837','CInfFrOperateA',10,0,0)
#判断获取数据长度是否足够。
if len(CInfFrOperateA)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(CInfFrOperateA)
```

|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	NIncBorrOthFI	|	向其他金融机构拆入资金净增加额	|
|	NIncDispTradFA	|	处置交易性金融资产净增加额	|
|	NIncDispFaFS	|	处置可供出售金融资产净增加额	|
|	IFCCashIncr	|	收取利息、手续费及佣金的现金	|
|	NIncFrBorr	|	拆入资金净增加额	|
|	NCApIncrRepur	|	回购业务资金净增加额	|
|	refundOfTax	|	收到的税费返还	|
|	CFrOthOperateA	|	收到其他与经营活动有关的现金	|
|	CInfFrOperateA	|	经营活动现金流入小计	|
|	CPaidIFC	|	支付利息、手续费及佣金的现金	|
|	CPaidToForEmpl	|	支付给职工以及为职工支付的现金	|
|	CPaidForTaxes	|	支付的各项税费	|
|	CPaidForOthOpA	|	支付其他与经营活动有关的现金	|
|	COutfOperateA	|	经营活动现金流出小计	|
|	NCFOperateA	|	经营活动产生的现金流量净额	|
|	procSellInvest	|	收回投资收到的现金	|
|	gainInvest	|	取得投资收益收到的现金	|
|	dispFixAssetsOth	|	处置固定资产、无形资产和其他长期资产收回的现金净额	|
|	NDispSubsOthBizC	|	处置子公司及其他营业单位收到的现金净额	|
|	CFrOthInvestA	|	收到其他与投资活动有关的现金	|
|	CInfFrInvestA	|	投资活动现金流入小计	|
|	purFixAssetsOth	|	购建固定资产、无形资产和其他长期资产支付的现金	|
|	CPaidInvest	|	投资支付的现金	|
|	NCPaidAcquis	|	取得子公司及其他营业单位支付的现金净额	|
|	CPaidOthInvestA	|	支付其他与投资活动有关的现金	|
|	COutfFrInvestA	|	投资活动现金流出小计	|
|	NCFFrInvestA	|	投资活动产生的现金流量净额	|
|	CFrCapContr	|	吸收投资收到的现金	|
|	CFrMinoSSubs	|	其中:子公司吸收少数股东投资收到的现金	|
|	CFrBorr	|	取得借款收到的现金	|
|	CFrIssueBond	|	发行债券收到的现金	|
|	CFrOthFinanA	|	收到其他与筹资活动有关的现金	|
|	CInfFrFinanA	|	筹资活动现金流入小计	|
|	CPaidForDebts	|	偿还债务支付的现金	|
|	CPaidDivProfInt	|	分配股利、利润或偿付利息支付的现金	|
|	divProfSubsMinoS	|	其中:子公司支付给少数股东的股利、利润	|
|	CPaidOthFinanA	|	支付其他与筹资活动有关的现金	|
|	COutfFrFinanA	|	筹资活动现金流出小计	|
|	NCFFrFinanA	|	筹资活动产生的现金流量净额	|
|	forexEffects	|	汇率变动对现金及现金等价物的影响	|
|	NChangeInCash	|	现金及现金等价物净增加额	|
|	NCEBegBal	|	加:期初现金及现金等价物余额	|
|	NCEEndBal	|	期末现金及现金等价物余额	|


# 银行业资产负债表


```py
#获取'归属于母公司所有者权益合计'财务字段。
TEquityAttrP = fin_balance_bx('SH600000','TEquityAttrP',10,0,0)
#判断获取数据长度是否足够。
if len(TEquityAttrP)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(TEquityAttrP)
```

|名称 | 描述 |
|:---------:|:----------:|
|	名称	|	描述	|
|	secID	|	市场+股票代码，如SH600318	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	cashCEquiv	|	货币资金	|
|	loanToOthBankFi	|	拆出资金	|
|	tradingFA	|	交易性金融资产	|
|	premiumReceiv	|	应收保费	|
|	reinsurReceiv	|	应收分保账款	|
|	intReceiv	|	应收利息	|
|	purResaleFa	|	买入返售金融资产	|
|	availForSaleFa	|	可供出售金融资产	|
|	htmInvest	|	持有至到期投资	|
|	LTEquityInvest	|	长期股权投资	|
|	investRealEstate	|	投资性房地产	|
|	fixedAssets	|	固定资产	|
|	intanAssets	|	无形资产	|
|	deferTaxAssets	|	递延所得税资产	|
|	derivAssets	|	衍生金融资产	|
|	subrogRecoReceiv	|	应收代位追偿款	|
|	RRReinsUnePrem	|	应收分保未到期责任准备金	|
|	RRReinsOutstdCla	|	应收分保未决赔款准备金	|
|	RRReinsLinsLiab	|	应收分保寿险责任准备金	|
|	RRReinsLThinsLiab	|	应收分保长期健康险责任准备金	|
|	PHPledgeLoans	|	保户质押贷款	|
|	fixedTermDepos	|	定期存款	|
|	refundCapDepos	|	存出资本保证金	|
|	indepAccAssets	|	独立账户资产	|
|	othAssets	|	其他资产	|
|	TAssets	|	资产总计	|
|	STBorr	|	短期借款	|
|	loanFrOthBankFi	|	拆入资金	|
|	tradingFL	|	交易性金融负债	|
|	soldForRepurFa	|	卖出回购金融资产款	|
|	commisPayable	|	应付手续费及佣金	|
|	payrollPayable	|	应付职工薪酬	|
|	taxesPayable	|	应交税费	|
|	reinsurPayable	|	应付分保账款	|
|	LTBorr	|	长期借款	|
|	bondPayable	|	应付债券	|
|	deferTaxLiab	|	递延所得税负债	|
|	derivLiab	|	衍生金融负债	|
|	premReceivAdva	|	预收保费	|
|	indemAccPayable	|	应付赔付款	|
|	policyDivPayable	|	应付保单红利	|
|	PHInvest	|	保户储金及投资款	|
|	reserUnePrem	|	未到期责任准备金	|
|	reserOutstdClaims	|	未决赔款准备金	|
|	reserLinsLiab	|	寿险责任准备金	|
|	reserLthinsLiab	|	长期健康险责任准备金	|
|	indeptAccLiab	|	独立账户负债	|
|	othLiab	|	其他负债	|
|	TLiab	|	负债合计	|
|	paidInCapital	|	实收资本(或股本)	|
|	capitalReser	|	资本公积	|
|	treasuryShare	|	减:库存股	|
|	surplusReser	|	盈余公积	|
|	ordinRiskReser	|	一般风险准备	|
|	retainedEarnings	|	未分配利润	|
|	forexDiffer	|	外币报表折算差额	|
|	TEquityAttrP	|	归属于母公司所有者权益合计	|
|	minorityInt	|	少数股东权益	|
|	TShEquity	|	所有者权益合计	|
|	TLiabEquity	|	负债和所有者权益总计	|
|	othEquityInstr	|	其他权益工具	|
|	othCompreIncome	|	其他综合收益	|

# 银行业利润分配表


```py
#获取'营业收入'财务字段数据
tRevenue = fin_profit_yh('SH600000','revenue',1,0,0)
print(tRevenue)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	revenue	|	营业收入	|
|	NIntIncome	|	利息净收入	|
|	intIncome	|	利息收入	|
|	intExp	|	利息支出	|
|	NCommisIncome	|	手续费及佣金净收入	|
|	commisIncome	|	手续费及佣金收入	|
|	commisExp	|	手续费及佣金支出	|
|	othOperRev	|	其他业务收入	|
|	COGS	|	营业支出	|
|	bizTaxSurchg	|	营业税金及附加	|
|	genlAdminExp	|	业务及管理费	|
|	assetsImpairLoss	|	资产减值损失	|
|	othOperCosts	|	其他业务成本	|
|	fValueChgGain	|	公允价值变动收益	|
|	investIncome	|	投资收益	|
|	AJInvestIncome	|	其中:对联营企业和合营企业的投资收益	|
|	forexGain	|	汇兑收益	|
|	operateProfit	|	营业利润	|
|	NoperateIncome	|	营业外收入	|
|	NoperateExp	|	营业外支出	|
|	TProfit	|	利润总额	|
|	incomeTax	|	所得税费用	|
|	NIncome	|	净利润	|
|	goingConcernNI	|	持续经营净利润	|
|	quitConcernNI	|	终止经营净利润	|
|	NIncomeAttrP	|	归属于母公司所有者的净利润	|
|	minorityGain	|	少数股东损益	|
|	basicEPS	|	基本每股收益	|
|	dilutedEPS	|	稀释每股收益	|
|	othComprIncome	|	其他综合收益	|
|	TComprIncome	|	综合收益总额	|
|	comprIncAttrP	|	归属于母公司所有者的综合收益总额	|
|	comprIncAttrMS	|	归属于少数股东的综合收益总额	|


#   银行业现金流量表


```py
#获取'归属于母公司所有者权益合计'财务字段。
CInfFrOperateA = fin_cashflow_yh('SH600000','CInfFrOperateA',10,0,0)
#判断获取数据长度是否足够。
if len(CInfFrOperateA)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(CInfFrOperateA)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	NDeposIncrCFI	|	客户存款和同业存放款项净增加额	|
|	NIncrBorrFrCB	|	向中央银行借款净增加额	|
|	NIncBorrOthFI	|	向其他金融机构拆入资金净增加额	|
|	NDecrInDisburOfLa	|	发放贷款及垫款净减少额	|
|	NDecrInDeposInFI	|	存放中央银行和同业款项净减少额	|
|	NDecrLoanToOthFI	|	向其他金融机构拆出资金净减少额	|
|	IFCCashIncr	|	收取利息、手续费及佣金的现金	|
|	CFrOthOperateA	|	收到其他与经营活动有关的现金	|
|	CInfFrOperateA	|	经营活动现金流入小计	|
|	NDeposDecrFrFI	|	客户存款和同业存放款项净减少额	|
|	NDecrBorrFrCB	|	向中央银行借款净减少额	|
|	NDecrBorrFrOthFI	|	向其他金融机构拆入资金净减少额	|
|	NIncDisburOfLA	|	客户贷款及垫款净增加额	|
|	NIncrDeposInFI	|	存放中央银行和同业款项净增加额	|
|	NIncrLoansToOthFi	|	向其他金融机构拆出资金净增加额	|
|	CPaidIFC	|	支付利息、手续费及佣金的现金	|
|	CPaidToForEmpl	|	支付给职工以及为职工支付的现金	|
|	CPaidForTaxes	|	支付的各项税费	|
|	CPaidForOthOpA	|	支付其他与经营活动有关的现金	|
|	COutfOperateA	|	经营活动现金流出小计	|
|	NCFOperateA	|	经营活动产生的现金流量净额	|
|	procSellInvest	|	收回投资收到的现金	|
|	gainInvest	|	取得投资收益收到的现金	|
|	dispFixAssetsOth	|	处置固定资产、无形资产和其他长期资产收回的现金净额	|
|	NDispSubsOthBizC	|	处置子公司及其他营业单位收到的现金净额	|
|	CFrOthInvestA	|	收到其他与投资活动有关的现金	|
|	CInfFrInvestA	|	投资活动现金流入小计	|
|	purFixAssetsOth	|	购建固定资产、无形资产和其他长期资产支付的现金	|
|	CPaidInvest	|	投资支付的现金	|
|	NCPaidAcquis	|	取得子公司及其他营业单位支付的现金净额	|
|	CPaidOthInvestA	|	支付其他与投资活动有关的现金	|
|	COutfFrInvestA	|	投资活动现金流出小计	|
|	NCFFrInvestA	|	投资活动产生的现金流量净额	|
|	CFrCapContr	|	吸收投资收到的现金	|
|	CFrMinoSSubs	|	其中:子公司吸收少数股东投资收到的现金	|
|	CFrIssueBond	|	发行债券收到的现金	|
|	CFrOthFinanA	|	收到其他与筹资活动有关的现金	|
|	CInfFrFinanA	|	筹资活动现金流入小计	|
|	CPaidForDebts	|	偿还债务支付的现金	|
|	CPaidDivProfInt	|	分配股利、利润或偿付利息支付的现金	|
|	divProfSubsMinoS	|	其中:子公司支付给少数股东的股利、利润	|
|	CPaidOthFinanA	|	支付其他与筹资活动有关的现金	|
|	COutfFrFinanA	|	筹资活动现金流出小计	|
|	NCFFrFinanA	|	筹资活动产生的现金流量净额	|
|	forexEffects	|	汇率变动对现金及现金等价物的影响	|
|	NChangeInCash	|	现金及现金等价物净增加额	|
|	NCEBegBal	|	加:期初现金及现金等价物余额	|
|	NCEEndBal	|	期末现金及现金等价物余额	|



# 保险业资产负债表

PEL仅支持通过一般工商业资产负债表获取保险类财务数据。

```py
#获取'归属于母公司所有者权益合计'财务字段。
TEquityAttrP = fin_balance_bx('SH601628','TEquityAttrP',10,0,0)
#判断获取数据长度是否足够。
if len(TEquityAttrP)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(TEquityAttrP)
```


|名称 | 描述 |
|:---------:|:----------:|
|	名称	|	描述	|
|	secID	|	市场+股票代码，如SH600318	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	cashCEquiv	|	货币资金	|
|	loanToOthBankFi	|	拆出资金	|
|	tradingFA	|	交易性金融资产	|
|	premiumReceiv	|	应收保费	|
|	reinsurReceiv	|	应收分保账款	|
|	intReceiv	|	应收利息	|
|	purResaleFa	|	买入返售金融资产	|
|	availForSaleFa	|	可供出售金融资产	|
|	htmInvest	|	持有至到期投资	|
|	LTEquityInvest	|	长期股权投资	|
|	investRealEstate	|	投资性房地产	|
|	fixedAssets	|	固定资产	|
|	intanAssets	|	无形资产	|
|	deferTaxAssets	|	递延所得税资产	|
|	derivAssets	|	衍生金融资产	|
|	subrogRecoReceiv	|	应收代位追偿款	|
|	RRReinsUnePrem	|	应收分保未到期责任准备金	|
|	RRReinsOutstdCla	|	应收分保未决赔款准备金	|
|	RRReinsLinsLiab	|	应收分保寿险责任准备金	|
|	RRReinsLThinsLiab	|	应收分保长期健康险责任准备金	|
|	PHPledgeLoans	|	保户质押贷款	|
|	fixedTermDepos	|	定期存款	|
|	refundCapDepos	|	存出资本保证金	|
|	indepAccAssets	|	独立账户资产	|
|	othAssets	|	其他资产	|
|	TAssets	|	资产总计	|
|	STBorr	|	短期借款	|
|	loanFrOthBankFi	|	拆入资金	|
|	tradingFL	|	交易性金融负债	|
|	soldForRepurFa	|	卖出回购金融资产款	|
|	commisPayable	|	应付手续费及佣金	|
|	payrollPayable	|	应付职工薪酬	|
|	taxesPayable	|	应交税费	|
|	reinsurPayable	|	应付分保账款	|
|	LTBorr	|	长期借款	|
|	bondPayable	|	应付债券	|
|	deferTaxLiab	|	递延所得税负债	|
|	derivLiab	|	衍生金融负债	|
|	premReceivAdva	|	预收保费	|
|	indemAccPayable	|	应付赔付款	|
|	policyDivPayable	|	应付保单红利	|
|	PHInvest	|	保户储金及投资款	|
|	reserUnePrem	|	未到期责任准备金	|
|	reserOutstdClaims	|	未决赔款准备金	|
|	reserLinsLiab	|	寿险责任准备金	|
|	reserLthinsLiab	|	长期健康险责任准备金	|
|	indeptAccLiab	|	独立账户负债	|
|	othLiab	|	其他负债	|
|	TLiab	|	负债合计	|
|	paidInCapital	|	实收资本(或股本)	|
|	capitalReser	|	资本公积	|
|	treasuryShare	|	减:库存股	|
|	surplusReser	|	盈余公积	|
|	ordinRiskReser	|	一般风险准备	|
|	retainedEarnings	|	未分配利润	|
|	forexDiffer	|	外币报表折算差额	|
|	TEquityAttrP	|	归属于母公司所有者权益合计	|
|	minorityInt	|	少数股东权益	|
|	TShEquity	|	所有者权益合计	|
|	TLiabEquity	|	负债和所有者权益总计	|
|	othEquityInstr	|	其他权益工具	|
|	othCompreIncome	|	其他综合收益	|



# 保险业利润分配表


```py
revenue = fin_profit_bx('SH601628','revenue',10,0,0)
#判断获取数据长度是否足够。
if len(revenue)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(revenue)
```



|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	revenue	|	营业收入	|
|	premEarned	|	已赚保费	|
|	grossPremWrit	|	保险业务收入	|
|	reinsIncome	|	其中:分保费收入	|
|	reinsur	|	减:分出保费	|
|	unePremReser	|	提取未到期责任准备金	|
|	commisExp	|	手续费及佣金支出	|
|	othOperRev	|	其他业务收入	|
|	COGS	|	营业支出	|
|	premRefund	|	退保金	|
|	compensPayout	|	赔付支出	|
|	compensPayoutRefu	|	减:摊回赔付支出	|
|	reserInsurLiab	|	提取保险责任准备金	|
|	insurLiabReserRefu	|	减:摊回保险责任准备金	|
|	policyDivPayt	|	保单红利支出	|
|	reinsurExp	|	分保费用	|
|	bizTaxSurchg	|	营业税金及附加	|
|	genlAdminExp	|	业务及管理费	|
|	reinsCostRefund	|	减:摊回分保费用	|
|	assetsImpairLoss	|	资产减值损失	|
|	othOperCosts	|	其他业务成本	|
|	fValueChgGain	|	公允价值变动收益	|
|	investIncome	|	投资收益	|
|	AJInvestIncome	|	其中:对联营企业和合营企业的投资收益	|
|	forexGain	|	汇兑收益	|
|	operateProfit	|	营业利润	|
|	NoperateIncome	|	营业外收入	|
|	NoperateExp	|	营业外支出	|
|	TProfit	|	利润总额	|
|	incomeTax	|	所得税费用	|
|	NIncome	|	净利润	|
|	NIncomeAttrP	|	归属于母公司所有者的净利润	|
|	minorityGain	|	少数股东损益	|
|	basicEPS	|	基本每股收益	|
|	dilutedEPS	|	稀释每股收益	|
|	othComprIncome	|	其他综合收益	|
|	TComprIncome	|	综合收益总额	|
|	comprIncAttrP	|	归属于母公司所有者的综合收益总额	|
|	comprIncAttrMS	|	归属于少数股东的综合收益总额	|


# 保险业现金流量表

```py
#获取'归属于母公司所有者权益合计'财务字段。
CInfFrOperateA = fin_cashflow_bx('SH601628','CInfFrOperateA',10,0,0)
#判断获取数据长度是否足够。
if len(CInfFrOperateA)<10:
    print("财务数据获取不足,请补充下载")
else:
    print(CInfFrOperateA)
```


|名称 | 描述 |
|:---------:|:----------:|
|	名称	|	描述	|
|	secID	|	证券内部ID	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	NDeposIncrCFI	|	客户存款和同业存放款项净增加额	|
|	NIncrBorrFrCB	|	向中央银行借款净增加额	|
|	premFrOrigContr	|	收到原保险合同保费取得的现金	|
|	NReinsurPrem	|	收到再保险业务现金净额	|
|	NIncPhDeposInv	|	保户储金及投资款净增加额	|
|	IFCCashIncr	|	收取利息、手续费及佣金的现金	|
|	refundOfTax	|	收到的税费返还	|
|	CFrOthOperateA	|	收到其他与经营活动有关的现金	|
|	CInfFrOperateA	|	经营活动现金流入小计	|
|	NIncDisburOfLA	|	客户贷款及垫款净增加额	|
|	NIncrDeposInFI	|	存放中央银行和同业款项净增加额	|
|	origContrCIndem	|	支付原保险合同赔付款项的现金	|
|	CPaidIFC	|	支付利息、手续费及佣金的现金	|
|	CPaidPolDiv	|	支付保单红利的现金	|
|	CPaidToForEmpl	|	支付给职工以及为职工支付的现金	|
|	CPaidForTaxes	|	支付的各项税费	|
|	CPaidForOthOpA	|	支付其他与经营活动有关的现金	|
|	COutfOperateA	|	经营活动现金流出小计	|
|	NCFOperateA	|	经营活动产生的现金流量净额	|
|	procSellInvest	|	收回投资收到的现金	|
|	gainInvest	|	取得投资收益收到的现金	|
|	dispFixAssetsOth	|	处置固定资产、无形资产和其他长期资产收回的现金净额	|
|	NDispSubsOthBizC	|	处置子公司及其他营业单位收到的现金净额	|
|	CFrOthInvestA	|	收到其他与投资活动有关的现金	|
|	CInfFrInvestA	|	投资活动现金流入小计	|
|	PurFixAssetsOth	|	购建固定资产、无形资产和其他长期资产支付的现金	|
|	CPaidInvest	|	投资支付的现金	|
|	NIncrPledgeLoan	|	质押贷款净增加额	|
|	NCPaidAcquis	|	取得子公司及其他营业单位支付的现金净额	|
|	CPaidOthInvestA	|	支付其他与投资活动有关的现金	|
|	COutfFrInvestA	|	投资活动现金流出小计	|
|	NCFFrInvestA	|	投资活动产生的现金流量净额	|
|	CFrCapContr	|	吸收投资收到的现金	|
|	CFrMinoSSubs	|	其中:子公司吸收少数股东投资收到的现金	|
|	CFrBorr	|	取得借款收到的现金	|
|	CFrIssueBond	|	发行债券收到的现金	|
|	CFrOthFinanA	|	收到其他与筹资活动有关的现金	|
|	CInfFrFinanA	|	筹资活动现金流入小计	|
|	CPaidForDebts	|	偿还债务支付的现金	|
|	CPaidDivProfInt	|	分配股利、利润或偿付利息支付的现金	|
|	divProfSubsMinoS	|	其中:子公司支付给少数股东的股利、利润	|
|	CPaidOthFinanA	|	支付其他与筹资活动有关的现金	|
|	COutfFrFinanA	|	筹资活动现金流出小计	|
|	NCFFrFinanA	|	筹资活动产生的现金流量净额	|
|	forexEffects	|	汇率变动对现金及现金等价物的影响	|
|	NChangeInCash	|	现金及现金等价物净增加额	|
|	NCEBegBal	|	加:期初现金及现金等价物余额	|
|	NCEEndBal	|	期末现金及现金等价物余额	|



# 衍生数据

## 衍生财务数据

```py
#获取衍生数据'每股收益'的财务数据
EPS = fin_indicator('SH600007','EPS',1,0,0)
```

|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	证券内部ID	|
|	endDate	|	截止日期	|
|	classification	|	一般行业：[0]， 保险：[1]，  证券：[2]， 银行：[3]	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	mergedFlag	|	合并类型。1-合并,2-母公司。对应DataAPI.SysCodeGet.codeTypeID=70003。	|
|	reportType	|	报告类型。1-一季度，2-半年度，3-三季度，4-年度。	|
|	tFixedAssets	|	固定资产合计 , 1、固定资产合计=固定资产+在建工程+工程物资+固定资产清理（金融企业不计算）	|
|		|	2、金融企业不计算	|
|	intFreeCl	|	无息流动负债 , 1、无息流动负债=应付账款+预收账款+应付股利+应付利息+应交税费+应付职工薪酬+其他应付款+预提费用+其他流动负债2、金融企业不计算3、一般工商业公司合并报表中有金融类负债科目看作带息流动负债，例如：吸收存款	|
|	intFreeNcl	|	无息非流动负债 , 1、无息非流动负债=非流动负债合计-（长期借款+应付债券）2、金融企业不计算	|
|	intCl	|	带息流动负债 , 1、带息流动负债=流动负债-无息流动负债2、金融企业不计算3、一般工商业公司合并报表中有金融类负债科目看作有息流动负债，例如：吸收存款	|
|	intDebt	|	带息债务 , 1、带息债务=带息流动负债+长期借款+应付债券2、金融企业不计算3、一般工商业公司合并报表中有金融类负债科目看作带息流动债务，例如：吸收存款	|
|	nDebt	|	净债务 , 1、净债务=带息负债-货币资金2、金融企业不计算3、一般工商业公司合并报表中有金融类负债科目看作带息负债，例如：吸收存款	|
|	nTanAssets	|	有形净资产 , 有形净资产=归属于母公司的所有者权益-无形资产-研发支出-商誉-长期待摊费用-递延所得税资产	|
|	workCapital	|	营运资本 , 1、营运资本=流动资产-流动负债2、金融企业不计算	|
|	nWorkCapital	|	净营运资本 , 1、净营运资本=流动资产-货币资金-无息流动负债2、金融企业不计算3、一般工商业公司合并报表中有金融类负债科目看作带息流动负债，例如：吸收存款	|
|	IC	|	投入资本 , 1、投入成本=所有者权益+带息债务2、金融企业不计算3、一般工商业公司合并报表中有金融类负债科目看作带息债务，例如：吸收存款	|
|	tRe	|	留存收益 , 留存收益=盈余公积+未分配利润	|
|	grossProfit	|	毛利 , 1、毛利=营业收入-营业成本2、金融企业不计算	|
|	opaProfit	|	经营活动净收益 , 1、对于非金融企业：经营活动净收益=营业总收入-营业总成本2、对于金融企业：经营活动净收益=营业收入-公允价值变动损益-投资收益-汇兑损益-营业支出	|
|	valChgProfit	|	价值变动净收益 , 价值变动净收益=公允价值变动损益+投资收益+汇兑损益	|
|	nIntExp	|	净利息费用 , 1、净利息费用=利息支出-利息收入（财务费用附注），若未披露财务费用附注，则直接取财务费用值2、金融企业不计算	|
|	EBIT	|	息税前利润 , 1、EBIT=利润总额+财务费用2、金融企业不计算	|
|	EBITDA	|	息税折旧摊销前利润 , 1、EBITDA=利润总额+财务费用+固定资产折旧＋无形资产摊销＋长期待摊费用摊销2、金融企业不计算	|
|	EBIAT	|	息前税后利润 , 1、EBIAT=利润总额+财务费用*（1-税率）2、税率=所得税费用/利润总额（实际税率）；若所得税费用或利润总额为负，税率=25%（名义税率）3、金融企业不计算	|
|	nrProfitLoss	|	非经常性损益 , 直接取公告披露值	|
|	niAttrPCut	|	扣除非经常性损益后的归属于上市公司股东的净利润 , 直接取公告披露值	|
|	FCFF	|	企业自由现金流量=利润总额-所得税+固定资产折旧-（购建固定资产、无形资产和其他长期资产支付的现金+投资支付的现金）-（期末营运资本-期初营运资本）4、金融企业不计算	|
|	FCFE	|	股权自由现金流量 , 1、FCFE=经营活动现金流量净额-资本支出+债务增加额-财务费用2、资本支出=购建固定资产、无形资产和其他长期资产支付的现金-处置固定资产、无形资产和其他长期资产收回的现金净额3、债务增加额=（期末短期借款+期末长期借款+期末应付债券）-（期初短期借款+期初长期借款+期初应付债券）4、金融企业不计算	|
|	DA	|	折旧与摊销 , 1、折旧及摊销=固定资产折旧＋无形资产摊销＋长期待摊费用摊销2、金融企业不计算	|

##  财务指标-每股

|名称 | 描述 |
|:---------:|:----------:|
|	EPS	|	每股收益(期末摊薄,元/股)	|
|	basicEPS	|	基本每股收益	|
|	dilutedEPS	|	稀释每股收益	|
|	nAssetPS	|	每股净资产(元/股)	|
|	tRevPS	|	每股营业总收入(元/股)	|
|	revPS	|	每股营业收入(元/股)	|
|	opPS	|	每股营业利润(元/股)	|
|	EBITPS	|	每股息税前利润(元/股)    1、金融企业不计算	|
|	cReserPS	|	每股资本公积(元/股)	|
|	sReserPS	|	每股盈余公积(元/股)	|
|	reserPS	|	每股公积金(元/股)	|
|	rePS	|	每股未分配利润(元/股)	|
|	tRePS	|	每股留存收益(元/股)	|
|	nCfOperAPS	|	每股经营活动产生的现金流量净额(元/股)	|
|	nCInCashPS	|	每股现金流量净额(元/股)	|
|	FCFFPS	|	每股企业自由现金流量(元/股)	|
|	FCFEPS	|	每股股东自由现金流量(元/股)    1、金融企业不计算	|

##  财务指标-成长能力

|名称 | 描述 |
|:---------:|:----------:|
|	tRevenueYOY	|	营业总收入同比增长(%)	|
|	revenueYOY	|	营业收入同比增长(%)	|
|	operProfitYOY	|	营业利润同比增长(%)	|
|	tProfitYOY	|	营业总额同比增长(%)	|
|	niYOY	|	净利润同比增长(%)	|
|	niAttrPYOY	|	归属于母公司净利润同比增长(%)	|
|	niAttrPCutYOY	|	归属于母公司净利润（扣除）同比增长(%)	|
|	basicEPSYOY	|	基本每股收益同比增长(%)	|
|	dilutedEPSYOY	|	稀释每股收益同比增长(%)	|
|	ROEYOY	|	净资产收益率（摊薄）同比增长(%)	|
|	nCfOpaYOY	|	经营活动产生的现金流量净额同比增长(%)	|
|	nCfOpaPSYOY	|	每股经营活动产生的现金流量净额同比增长(%)	|
|	taYTD	|	总资产相对年初增长(%)	|
|	naYTD	|	净资产相对年初增长(%)	|
|	teAttrPYTD	|	归属于母公司的股东权益相对年初增长(%)	|
|	naPSYTD	|	每股净资产相对年初增长(%)	|
|	FixedYOY	|	固定资产增长率=(期末固定资产-期初固定资产)/期初固定资产	|
|	TAssetsYOY	|	总资产增长率=(期末总资产-期初总资产)/期初总资产	|
|	TEquityAttrPYOY	|	归属母公司净资产增长率=(期末归属母公司股东权益-期初归属母公司股东权益)/期初归属母公司股东权益	|
|	TShEquityYOY	|	净资产增长率=(期末所有者股东权益-期初所有者股东权益)/期初所有者股东权益	|

##  财务指标-收现能力

|名称 | 描述 |
|:---------:|:----------:|
|	arR	|	应收账款/营业收入(%)	|
|	advRR	|	预收款项/营业收入(%)	|
|	CFsgsR	|	销售商品提供劳务收到的现金/营业收入(%)	|
|	nCFOpaTR	|	经营活动产生的现金流量净额/营业总收入(%)	|
|	nCFOpaR	|	经营活动产生的现金流量净额/营业收入(%)	|
|	nCFOpaOpap	|	经营活动产生的现金流量净额/经营活动净收益(%)	|
|	nCFOpaOp	|	经营活动产生的现金流量净额/营业利润(%)	|
|	pFixAODa	|	投资支出/折旧和摊销(%)    1、金融企业不计算	|
|	cRcvryA	|	全部资产现金回收率(%),全部资产现金回收率=经营活动现金流量净额/当期资产总额	|
|	nCFOpaPropt	|	经营活动产生的现金流量净额占比(%)	|
|	nCFIaPropt	|	投资活动产生的现金流量净额占比(%)	|
|	nCFFaPropt	|	筹资活动产生的现金流量净额占比(%)	|
|	NCFOperateAYOY	|	营业现金增长比率=(期末经营活动产生的现金流量净额-期初经营活动产生的现金流量净额)/期初经营活动产生的现金流量净额	|
|	CCERatio	|	经营现金资本性支出比率=经营活动产生的现金流量净额/(期末固定资产-期初固定资产+期末无形资产-期初无形资产)	|
|	OCDERatio	|	经营现金折旧费用比率=固定资产折旧/经营活动产生的现金流量净额	|
|	Operatingindex	|	营运指数=经营活动产生的现金流量净额/经营活动现金流入小计	|

## 财务指标-盈利能力

|名称 | 描述 |
|:---------:|:----------:|
|	grossMARgin	|	销售毛利率(%) , 销售毛利率=（营业收入-营业成本）/营业收入*100%	|
|	npMARgin	|	销售净利润率(%) , 销售净利率=净利润/营业收入*100%	|
|	ROE	|	净资产收益率(摊薄,%) , ROE(摊薄)=归属于母公司的净利润/期末归属于母公司的所有者权益*100%	|
|	ROEA	|	净资产收益率(平均,%) , ROE(平均)=归属于母公司的净利润*2/（期末归属于母公司的所有者权益+期初归属于股公司的所有者权益）*100%	|
|	ROEW	|	净资产收益率(加权平均,%) , 直接取公告披露值	|
|	ROECut	|	净资产收益率(扣除摊薄,%) ,ROE（扣除摊薄）=扣非归属于母公司的净利润/期末归属于母公司的所有者权益 扣非归属于母公司的净利润取公司披露值，若未披露则：归属于母公司净利润-非经常性损益	|
|	ROECutW	|	净资产收益率(扣除加权平均,%) , 直接取公告披露值	|
|	ROA	|	总资产净利率(%) , ROA=净利润*2/(期初总资产+期末总资产)	|
|	ROAEBIT	|	总资产报酬率(%) , ROA(EBIT)=EBIT*2/(期初总资产+期末总资产)	|
|	ROIC	|	投入资本回报率(%) , ROIC=EBIT*（1-所得税/利润总额）/(长期计息负债+短期计息负债+所有者权益）   1、金融企业不计算	|
|	opMARgin	|	主营业务利润率=营业利润/营业收入	|
|	niTeap	|	所有者权益收益率=净利润/所有者权益	|
|	nCFOpaNi	|	盈利现金比率 = 经营活动净现金流 / 净利润	|


## 财务指标-营运能力

|名称 | 描述 |
|:---------:|:----------:|
|	faTurnover	|	固定资产周转率(次) , 1、固定资产周转率=总营业收入*2/(期初固定资产+期末固定资产) 2、若期初固定资产为空或0，直接使用期末固定资产计算	|
|	tfaTurnover	|	固定资产合计周转率(次) , 1、固定资产合计周转率=营业总收入*2/(期初固定资产合计+期末固定资产合计) 2、若期初固定资产合计为空或0，直接使用期末固定资产合计计算  3、金融企业不计算	|
|	caTurnover	|	流动资产周转率(次) , 1、流动资产周转率=总营业收入*2/(期初流动资产+期末流动资产) 2、若期初流动资产为空或0，直接使用期末流动资产计算	|
|	taTurnover	|	总资产周转率(次) , 1、总资产周转率=总营业收入*2/(期初总资产+期末总资产) 2、若期初总资产为空或0，直接使用期末总资产计算	|
|	invenTurnover	|	存货周转率(次) , 1、存货周转率=营业成本*2/(期初存货+期末存货) 2、若期初存货为空或0，直接使用期末存货计算	|
|	daysInven	|	存货周转天数（天/次） , Q1:存货周转天数=90/存货周转率 S1:存货周转天数=180/存货周转率 CQ3:存货周转天数=270/存货周转率 A:存货周转天数=360/存货周转率	|
|	ARTurnover	|	应收账款周转率(次) , 应收账款周转率=营业收入*2/(期初应收账款+期末应收账款)	|
|	daysAR	|	应收账款周转天数(天/次) , Q1:应收账款周转天数=90/应收账款周转率 S1:应收账款周转天数=180/应收账款周转率 CQ3:应收账款周转天数=270/应收账款周转率 A:应收账款周转天数=360/应收账款周转率	|
|	operCycle	|	营业周期(天/次) , 营业周期=存货周转天数+应收账款周转天数	|
|	APTurnover	|	应付账款周转率(次) ,	|
|		|	应付账款周转率=(营业成本+期末存货+期初存货)*2/(期初应付账款+期末应付账款)	|
|	daysAP	|	应付账款周转天数(天/次) , Q1:应付账款周转天数=90/应付账款周转率 S1:应付账款周转天数=180/应付账款周转率 CQ3:应付账款周转天数=270/应付账款周转率 A:应付账款周转天数=360/应付账款周转率	|
|	OCCdays	|	经营性循环周期=存货周转天数＋应收账款周转天数－应付账款周转天数	|
|	LtermCapRatio	|	长期资金适合率=(资产总计-流动资产合计)/(非流动负债合计+归属母公司股东权益)	|


##  财务指标-偿债能力

|名称 | 描述 |
|:---------:|:----------:|
|	currenTRatio	|	流动比率,流动比率=流动资产/流动负债	|
|	quickRatio	|	速动比率,速动比率=（流动资产-存货）/流动负债	|
|	squickRatio	|	保守速动比率,保守速动比率=（货币资金+交易性金融资产+应收票据+应收账款+其他应收款）/流动负债	|
|	opCL	|	营业利润/流动负债	|
|	opTL	|	营业利润/负债合计	|
|	asseTLiabRatio	|	资产负债率(%),资产负债率=负债总计/资产总计*100%	|
|	equityRatio	|	产权比率,产权比率=负债总计/所有者权益合计	|
|	TLTeap	|	负债合计/归属于母公司的股东权益	|
|	teapTL	|	归属于母公司的股东权益/负债合计	|
|	teapID	|	归属于母公司的股东权益/带息债务	|
|	nTanATL	|	有形净资产/负债合计	|
|	nTanAID	|	有形净资产/带息债务 注：金融类不计	|
|	nTanANd	|	有形净资产/净债务   注：金融类不计	|
|	EBITDATL	|	息税折旧摊销前利润/负债合计  注：金融类不计 |
|	EBITDAID	|	息税折旧摊销前利润/带息债务  注：金融类不计	|
|	cashICL	|	货币资金/带息流动负债	注：金融类不计 |
|	cashCL	|	货币资金/流动负债	|
|	nCFOpaCL	|	营业现金流动负债比=经营活动现金流量净额/流动负债	|
|	nCFOpaLiab	|	营业现金流动负债比=经营活动现金流量净额/负债合计	|
|	nCFOpaID	|	经营活动现金流量净额/带息债务	注：金融类不计|
|	nCFOpaNd	|	经营活动现金流量净额/净债务 	注：金融类不计|
|	nCFOpaNCL	|	经营活动现金流量净额/非流动负债	|
|	nCFNfaCL	|	非筹资性现金流量净额/流动负债	|
|	nCFNfaLiab	|	非筹资性现金流量净额/负债总额	|
|	nCLWc	|	非流动负债与营运资金比率,非流动负债与营运资金比率=非流动负债合计/（流动资产-流动负债） 1、金融企业不计算	|
|	timesInteEBIT	|	EBIT利息保障倍数(倍),EBIT利息保障倍数=EBIT/利息费用	|
|	timesInteEBITDA	|	EBITDA利息保障倍数(倍),EBITDA利息保障倍数=EBITDA/利务费用	|
|	timesInteCF	|	现金流量利息保障倍数(倍),现金流量利息保障倍数=经营活动现金流量净额/利务费用	|
|	quickRatio2	|	速动比率=(流动资产-存货-待摊费用-一年到期非流动资产)/流动负债	|
|	cashFACL	|	现金流动负债比=（货币资金+交易性金融资产）/流动负债	|

## 财务指标-利润表结构分析

|名称 | 描述 |
|:---------:|:----------:|
|	rTR	|	营业收入/营业总收入(%)	|
|	TCOGSTR	|	营业总成本/营业总收入(%)	|
|	COGSTR	|	营业成本/营业总收入(%)	|
|	btaxSurchgTR	|	营业税金及附加/营业总收入(%)	|
|	periodExpTR	|	期间费用比重=期间费用/营业总收入(%)	|
|	sellExpTR	|	销售费用/营业总收入(%)	|
|	adminExpTR	|	管理费用/营业总收入(%)	|
|	finanExpTR	|	财务费用/营业总收入(%)	|
|	ailTR	|	资产减值损失 /营业总收入(%)	|
|	opaPTR	|	经营活动净收益/营业总收入(%)	|
|	valChgPTR	|	价值变动净收益/营业总收入(%)	|
|	fvChgGTR	|	公允价值变动收益/营业总收入(%)	|
|	invIncTR	|	投资收益/营业总收入(%)	|
|	opTR	|	营业利润/营业总收入(%)	|
|	nopgTR	|	营业外收入/营业总收入(%)	|
|	noplTR	|	营业外支出/营业总收入(%)	|
|	tpTR	|	利润总额/营业总收入(%)	|
|	itTR	|	所得税/营业总收入(%)	|
|	NITR	|	净利润/营业总收入(%)	|
|	EBITDATR	|	EBITDA/营业总收入(%)   1、金融企业不计算	|
|	EBITTR	|	EBIT/营业总收入(%)   1、金融企业不计算	|
|	opaPTp	|	经营活动净收益/利润总额(%)	|
|	valChgPTp	|	价值变动净收益/利润总额(%)	|
|	opTp	|	主营利润比重=营业利润/利润总额(%)	|
|	nNopiTp	|	营业外收支净额/利润总额(%)	|
|	itTp	|	所得税/利润总额(%)	|
|	NICutNI	|	扣除非经常损益后的归母净利润/归母净利润(%)	|
|	adminExpTR2	|	期间成本费用率 = （ 营业成本 + 管理费用 + 财务费用 + 销售费用 ） / 总营业收入	|

## 财务指标-资产负债表结构分析

|名称 | 描述 |
|:---------:|:----------:|
|	cTa	|	货币资金/总资产(%)	|
|	arTa	|	应收账款/总资产(%)	|
|	repayTa	|	预付账款/总资产(%)	|
|	invenTa	|	存货/总资产(%)	|
|	caTa	|	流动资产/总资产(%)	|
|	fixedATa	|	固定资产/总资产(%)	|
|	tFixedATa	|	固定资产合计/总资产(%) 金融不计	|
|	intanATa	|	无形资产/总资产(%)	|
|	ltAmorExpTa	|	长期待摊费用/总资产(%)	|
|	ncaTa	|	非流动资产/总资产(%)	|
|	apTa	|	应付账款/总资产(%)	|
|	advRTa	|	预收款项/总资产(%)	|
|	stBorrTa	|	短期借款/总资产(%)	|
|	ltBorrTa	|	长期借款/总资产(%)	|
|	bpTa	|	应付债券/总资产(%)	|
|	nTanATa	|	有形净资产/总资产(%)	|
|	treTa	|	留存收益/总资产(%)	|
|	teapTa	|	归属于母公司的股东权益/总资产(%)	|
|	tseTa	|	所有者权益/总资产(%)	|
|	idIc	|	带息债务/投入资本(%)   1、金融企业不计算	|
|	teapIc	|	归属于母公司的股东权益/投入资本(%)   1、金融企业不计算	|
|	clTa	|	流动负债/负债合计(%)	|
|	nclTa	|	非流动负债/负债合计(%)	|
|	equMultiplier	|	权益乘数(倍), 权益乘数=总资产/所有者股东权益	|
|	capFixRatio	|	资本固定化比率(%), 资本固定化比率=(总资产-流动资产)/归属于母公司的股东权益	|
|	DTAssetRatio	|	债务有形资产比率=负债合计/(归属母公司股东权益-无形资产)	|
|	DebtStrRatio	|	负债结构比率=流动负债/非流动负债	|
|	LTLEquityRatio	|	长期负债权益比=非流动负债/归属母公司股东权益	|
|	STIRLiab	|	短期计息负债 = 短期借款 + 应付票据 + 一年内到期的长期借款（一年内到期的非流动负债）	|
|	LTIRLiab	|	长期计息负债 = 长期借款 + 应付债券	|
|	TotalIRliab	|	计息负债总额 = 长期计息借款 + 短期计息借款	|
|	Netdebt	|	净负债 = 计息借款总额 - 货币资金	|
|	LTCapitRatio	|	长期资本化比率 = 长期计息借款 / （ 长期计息借款 + 所有者权益 + 少数股东权益 ）	|
|	TotalCapiRatio	|	总资本化比率 = 计息借款总额 / （ 计息借款总额 + 所有者权益 + 少数股东权益 ）	|



# 股本结构

## 公司股本结构表

```py
#获取总股本
totalShares = fin_com_share('SH600007','totalShares',1,0)
print(totalShares)
```

|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	changeDate	|	变更日期	|
|	totalShares	|	总股本	|
|	sharesA	|	A股	|
|	sharesB	|	B股	|
|	floatA	|	流通A股	|
|	floatB	|	流通B股	|
|	restShares	|	有限售条件股份合计	|
|	nonrestFloatShares	|	无限售流通股份合计	|


## 限售解禁明细

```py
listShares = fin_limited_list('SH600007','listShares',1,0)
print(listShares)
```

|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	publishDate	|	发布日期	|
|	Expecteddate	|	预计上市日期	|
|	floatDate	|	流通日期，输入格式“YYYYMMDD”	|
|	beginDate	|	起始日期	|
|	endDate	|	终止日期	|
|	listShares	|	上市数量(股)	|
|	marketableValues	|	解禁市值（元）	|



# IPO信息
```py
#获取600789'上市日期'。
listDate = fin_stock_information('SH600789','listDate')
#判断获取数据长度是否足够。
if len(listDate)<1:
    print("财务数据获取不足,请补充下载")
else:
    print(listDate)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	publishDate	|	发布日期	|
|	onlineIssueDate	|	网上发行日期	|
|	listDate	|	上市日期	|
|	issuePrice	|	发行价格	|
|	issueShares	|	股票发行量	|
|	onlineIssueShares	|	网上发行股数	|
|	offlineIssueShares	|	网下发行股数	|
|	newIssueShares	|	新股发行量	|
|	transShares	|	老股转让数量	|
|	newIssueRaiseCap	|	新股募集资金	|
|	OldShareRaiseCap	|	老股募集资金	|
|	issuePE	|	发行市盈率	|
|	onlineIssueLottoRatio	|	中签率	|
|	onlineIssueCode	|	网上申购代码	|
|	firstDayOpenPrice	|	上市首日开盘价	|
|	firstDayClosePrice	|	上市首日收盘价	|
|	onlineSubMax	|	个人申购上限(股)	|
|	onlineSubMin	|	最小申购数量(股)	|
|	listStatusCD	|	0-正常;1-已发行未上市;2-暂停上市;3-摘牌;4-发行失败;5-退市整理	|
|	delistDate	|	摘牌日期	|
|	equTypeCD	|	股票分类编码。例如，A-A股；B-B股。	|

# 股东研究

## 持股股东户数

```py
#得到'SH600007'品种的持股股东户数
shNum = fin_com_holder('SH600007','shNum',1,0,0)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期	|
|	shNum	|	股东总户数(户)	|
|	avgHoldNum	|	户均持股数(股)	|
|	AshNum	|	A股东总户数(户)	|
|	BshNum	|	B股东总户数(户)	|
|	shNumRingRatio	|	持股数环比	|

## 公司十大股东


```py
#获得排名第二的股东名称
holder_top = fin_holder_top10('SH600007','shName',2,1,0,0)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期，输入格式“YYYYMMDD”	|
|	shNum	|	股东序号	|
|	shName	|	股东名称	|
|	holdVol	|	持股数	|
|	holdPct	|	持股比例	|
|	shareType	|	股份性质	|

## 公司十大流通股东


```py
#获得排名第二的股东名称
holder_top = fin_tradableshare_top10('SH600007','shName',2,1,0,0)
```


|名称 | 描述 |
|:---------:|:----------:|
|	secID	|	市场+股票代码，如SH600007	|
|	ticker	|	股票代码	|
|	secShortName	|	证券简称	|
|	publishDate	|	发布日期	|
|	endDate	|	截止日期，输入格式“YYYYMMDD”	|
|	shNum	|	股东序号	|
|	shName	|	股东名称	|
|	holdVol	|	持无限售条件股份数量	|
|	holdPct	|	持股比例	|
|	shareType	|	股份性质	|


# 申万行业分类


```py
#获取该品种的三级分类名称
industryName = fin_com_swhy2014('SH600007','industryName3')
```

|名称 | 描述 |
|:---------:|:----------:|
|	secID	     |	市场+股票代码，如SH600007	|
|	ticker	     |	交易代码	|
|	secShortName |		证券简称	|
|	industryID1  |		一级行业编码	|
|	industryName1|		一级行业	|
|	industryID2	 |	二级行业编码	|
|	industryName2|		二级行业	|
|	industryID3	 |	三级行业编码	|
|	industryName3|		三级行业	|

## 申万行业代码2014版


|	一级代码	|	名称	|	二级代码	|	名称	|	三级代码	|	名称	|
|:---------:|:----------:|:---------:|:----------:|:---------:|:----------:|
|	110000	|	农林牧渔	|	110100	|	种植业	|	110101	|	种子生产	|
|	110000	|	农林牧渔	|	110100	|	种植业	|	110102	|	粮食种植	|
|	110000	|	农林牧渔	|	110100	|	种植业	|	110103	|	其他种植业	|
|	110000	|	农林牧渔	|	110200	|	渔业	|	110201	|	海洋捕捞	|
|	110000	|	农林牧渔	|	110200	|	渔业	|	110202	|	水产养殖	|
|	110000	|	农林牧渔	|	110300	|	林业	|	110301	|	林业	|
|	110000	|	农林牧渔	|	110400	|	饲料	|	110401	|	饲料	|
|	110000	|	农林牧渔	|	110500	|	农产品加工	|	110501	|	果蔬加工	|
|	110000	|	农林牧渔	|	110500	|	农产品加工	|	110502	|	粮油加工	|
|	110000	|	农林牧渔	|	110500	|	农产品加工	|	110504	|	其他农产品加工	|
|	110000	|	农林牧渔	|	110600	|	农业综合	|	110601	|	农业综合	|
|	110000	|	农林牧渔	|	110700	|	畜禽养殖	|	110701	|	畜禽养殖	|
|	110000	|	农林牧渔	|	110800	|	动物保健	|	110801	|	动物保健	|
|	210000	|	采掘	|	210100	|	石油开采	|	210101	|	石油开采	|
|	210000	|	采掘	|	210200	|	煤炭开采	|	210201	|	煤炭开采	|
|	210000	|	采掘	|	210200	|	煤炭开采	|	210202	|	焦炭加工	|
|	210000	|	采掘	|	210300	|	其他采掘	|	210301	|	其他采掘	|
|	210000	|	采掘	|	210400	|	采掘服务	|	210401	|	油气钻采服务	|
|	210000	|	采掘	|	210400	|	采掘服务	|	210402	|	其他采掘服务	|
|	220000	|	化工	|	220100	|	石油化工	|	220101	|	石油加工	|
|	220000	|	化工	|	220100	|	石油化工	|	220103	|	石油贸易	|
|	220000	|	化工	|	220200	|	化学原料	|	220201	|	纯碱	|
|	220000	|	化工	|	220200	|	化学原料	|	220202	|	氯碱	|
|	220000	|	化工	|	220200	|	化学原料	|	220203	|	无机盐	|
|	220000	|	化工	|	220200	|	化学原料	|	220204	|	其他化学原料	|
|	220000	|	化工	|	220300	|	化学制品	|	220301	|	氮肥	|
|	220000	|	化工	|	220300	|	化学制品	|	220302	|	磷肥	|
|	220000	|	化工	|	220300	|	化学制品	|	220303	|	农药	|
|	220000	|	化工	|	220300	|	化学制品	|	220304	|	日用化学产品	|
|	220000	|	化工	|	220300	|	化学制品	|	220305	|	涂料油漆油墨制造	|
|	220000	|	化工	|	220300	|	化学制品	|	220306	|	钾肥	|
|	220000	|	化工	|	220300	|	化学制品	|	220307	|	民爆用品	|
|	220000	|	化工	|	220300	|	化学制品	|	220308	|	纺织化学用品	|
|	220000	|	化工	|	220300	|	化学制品	|	220309	|	其他化学制品	|
|	220000	|	化工	|	220300	|	化学制品	|	220310	|	复合肥	|
|	220000	|	化工	|	220300	|	化学制品	|	220311	|	氟化工及制冷剂	|
|	220000	|	化工	|	220300	|	化学制品	|	220312	|	磷化工及磷酸盐	|
|	220000	|	化工	|	220300	|	化学制品	|	220313	|	聚氨酯	|
|	220000	|	化工	|	220300	|	化学制品	|	220314	|	玻纤	|
|	220000	|	化工	|	220400	|	化学纤维	|	220401	|	涤纶	|
|	220000	|	化工	|	220400	|	化学纤维	|	220402	|	维纶	|
|	220000	|	化工	|	220400	|	化学纤维	|	220403	|	粘胶	|
|	220000	|	化工	|	220400	|	化学纤维	|	220404	|	其他纤维	|
|	220000	|	化工	|	220400	|	化学纤维	|	220405	|	氨纶	|
|	220000	|	化工	|	220500	|	塑料	|	220501	|	其他塑料制品	|
|	220000	|	化工	|	220500	|	塑料	|	220502	|	合成革	|
|	220000	|	化工	|	220500	|	塑料	|	220503	|	改性塑料	|
|	220000	|	化工	|	220600	|	橡胶	|	220601	|	轮胎	|
|	220000	|	化工	|	220600	|	橡胶	|	220602	|	其他橡胶制品	|
|	220000	|	化工	|	220600	|	橡胶	|	220603	|	炭黑	|
|	230000	|	钢铁	|	230100	|	钢铁	|	230101	|	普钢	|
|	230000	|	钢铁	|	230100	|	钢铁	|	230102	|	特钢	|
|	240000	|	有色金属	|	240200	|	金属非金属新材料	|	240201	|	金属新材料	|
|	240000	|	有色金属	|	240200	|	金属非金属新材料	|	240202	|	磁性材料	|
|	240000	|	有色金属	|	240200	|	金属非金属新材料	|	240203	|	非金属新材料	|
|	240000	|	有色金属	|	240300	|	工业金属	|	240301	|	铝	|
|	240000	|	有色金属	|	240300	|	工业金属	|	240302	|	铜	|
|	240000	|	有色金属	|	240300	|	工业金属	|	240303	|	铅锌	|
|	240000	|	有色金属	|	240400	|	黄金	|	240401	|	黄金	|
|	240000	|	有色金属	|	240500	|	稀有金属	|	240501	|	稀土	|
|	240000	|	有色金属	|	240500	|	稀有金属	|	240502	|	钨	|
|	240000	|	有色金属	|	240500	|	稀有金属	|	240503	|	锂	|
|	240000	|	有色金属	|	240500	|	稀有金属	|	240504	|	其他稀有小金属	|
|	270000	|	电子	|	270100	|	半导体	|	270101	|	集成电路	|
|	270000	|	电子	|	270100	|	半导体	|	270102	|	分立器件	|
|	270000	|	电子	|	270100	|	半导体	|	270103	|	半导体材料	|
|	270000	|	电子	|	270200	|	元件	|	270202	|	印制电路板	|
|	270000	|	电子	|	270200	|	元件	|	270203	|	被动元件	|
|	270000	|	电子	|	270300	|	光学光电子	|	270301	|	显示器件	|
|	270000	|	电子	|	270300	|	光学光电子	|	270302	|	LED	|
|	270000	|	电子	|	270300	|	光学光电子	|	270303	|	光学元件	|
|	270000	|	电子	|	270400	|	其他电子	|	270401	|	其他电子	|
|	270000	|	电子	|	270500	|	电子制造	|	270501	|	电子系统组装	|
|	270000	|	电子	|	270500	|	电子制造	|	270502	|	电子零部件制造	|
|	280000	|	汽车	|	280100	|	汽车整车	|	280101	|	乘用车	|
|	280000	|	汽车	|	280100	|	汽车整车	|	280102	|	商用载货车	|
|	280000	|	汽车	|	280100	|	汽车整车	|	280103	|	商用载客车	|
|	280000	|	汽车	|	280200	|	汽车零部件	|	280201	|	汽车零部件	|
|	280000	|	汽车	|	280300	|	汽车服务	|	280301	|	汽车服务	|
|	280000	|	汽车	|	280400	|	其他交运设备	|	280401	|	其他交运设备	|
|	330000	|	家用电器	|	330100	|	白色家电	|	330101	|	冰箱	|
|	330000	|	家用电器	|	330100	|	白色家电	|	330102	|	空调	|
|	330000	|	家用电器	|	330100	|	白色家电	|	330103	|	洗衣机	|
|	330000	|	家用电器	|	330100	|	白色家电	|	330104	|	小家电	|
|	330000	|	家用电器	|	330100	|	白色家电	|	330105	|	家电零部件	|
|	330000	|	家用电器	|	330200	|	视听器材	|	330201	|	彩电	|
|	330000	|	家用电器	|	330200	|	视听器材	|	330202	|	其它视听器材	|
|	340000	|	食品饮料	|	340300	|	饮料制造	|	340301	|	白酒	|
|	340000	|	食品饮料	|	340300	|	饮料制造	|	340302	|	啤酒	|
|	340000	|	食品饮料	|	340300	|	饮料制造	|	340303	|	其他酒类	|
|	340000	|	食品饮料	|	340300	|	饮料制造	|	340304	|	软饮料	|
|	340000	|	食品饮料	|	340300	|	饮料制造	|	340305	|	葡萄酒	|
|	340000	|	食品饮料	|	340300	|	饮料制造	|	340306	|	黄酒	|
|	340000	|	食品饮料	|	340400	|	食品加工	|	340401	|	肉制品	|
|	340000	|	食品饮料	|	340400	|	食品加工	|	340402	|	调味发酵品	|
|	340000	|	食品饮料	|	340400	|	食品加工	|	340403	|	乳品	|
|	340000	|	食品饮料	|	340400	|	食品加工	|	340404	|	食品综合	|
|	350000	|	纺织服装	|	350100	|	纺织制造	|	350101	|	毛纺	|
|	350000	|	纺织服装	|	350100	|	纺织制造	|	350102	|	棉纺	|
|	350000	|	纺织服装	|	350100	|	纺织制造	|	350103	|	丝绸	|
|	350000	|	纺织服装	|	350100	|	纺织制造	|	350104	|	印染	|
|	350000	|	纺织服装	|	350100	|	纺织制造	|	350105	|	辅料	|
|	350000	|	纺织服装	|	350100	|	纺织制造	|	350106	|	其他纺织	|
|	350000	|	纺织服装	|	350200	|	服装家纺	|	350202	|	男装	|
|	350000	|	纺织服装	|	350200	|	服装家纺	|	350203	|	女装	|
|	350000	|	纺织服装	|	350200	|	服装家纺	|	350204	|	休闲服装	|
|	350000	|	纺织服装	|	350200	|	服装家纺	|	350205	|	鞋帽	|
|	350000	|	纺织服装	|	350200	|	服装家纺	|	350206	|	家纺	|
|	350000	|	纺织服装	|	350200	|	服装家纺	|	350207	|	其他服装	|
|	360000	|	轻工制造	|	360100	|	造纸	|	360101	|	造纸	|
|	360000	|	轻工制造	|	360200	|	包装印刷	|	360201	|	包装印刷	|
|	360000	|	轻工制造	|	360300	|	家用轻工	|	360302	|	家具	|
|	360000	|	轻工制造	|	360300	|	家用轻工	|	360303	|	其他家用轻工	|
|	360000	|	轻工制造	|	360300	|	家用轻工	|	360304	|	珠宝首饰	|
|	360000	|	轻工制造	|	360300	|	家用轻工	|	360305	|	文娱用品	|
|	360000	|	轻工制造	|	360400	|	其他轻工制造	|	360401	|	其他轻工制造	|
|	370000	|	医药生物	|	370100	|	化学制药	|	370101	|	化学原料药	|
|	370000	|	医药生物	|	370100	|	化学制药	|	370102	|	化学制剂	|
|	370000	|	医药生物	|	370200	|	中药	|	370201	|	中药	|
|	370000	|	医药生物	|	370300	|	生物制品	|	370301	|	生物制品	|
|	370000	|	医药生物	|	370400	|	医药商业	|	370401	|	医药商业	|
|	370000	|	医药生物	|	370500	|	医疗器械	|	370501	|	医疗器械	|
|	370000	|	医药生物	|	370600	|	医疗服务	|	370601	|	医疗服务	|
|	410000	|	公用事业	|	410100	|	电力	|	410101	|	火电	|
|	410000	|	公用事业	|	410100	|	电力	|	410102	|	水电	|
|	410000	|	公用事业	|	410100	|	电力	|	410103	|	燃机发电	|
|	410000	|	公用事业	|	410100	|	电力	|	410104	|	热电	|
|	410000	|	公用事业	|	410100	|	电力	|	410105	|	新能源发电	|
|	410000	|	公用事业	|	410200	|	水务	|	410201	|	水务	|
|	410000	|	公用事业	|	410300	|	燃气	|	410301	|	燃气	|
|	410000	|	公用事业	|	410400	|	环保工程及服务	|	410401	|	环保工程及服务	|
|	420000	|	交通运输	|	420100	|	港口	|	420101	|	港口	|
|	420000	|	交通运输	|	420200	|	高速公路	|	420201	|	高速公路	|
|	420000	|	交通运输	|	420300	|	公交	|	420301	|	公交	|
|	420000	|	交通运输	|	420400	|	航空运输	|	420401	|	航空运输	|
|	420000	|	交通运输	|	420500	|	机场	|	420501	|	机场	|
|	420000	|	交通运输	|	420600	|	航运	|	420601	|	航运	|
|	420000	|	交通运输	|	420700	|	铁路运输	|	420701	|	铁路运输	|
|	420000	|	交通运输	|	420800	|	物流	|	420801	|	物流	|
|	430000	|	房地产	|	430100	|	房地产开发	|	430101	|	房地产开发	|
|	430000	|	房地产	|	430200	|	园区开发	|	430201	|	园区开发	|
|	450000	|	商业贸易	|	450200	|	贸易	|	450201	|	贸易	|
|	450000	|	商业贸易	|	450300	|	一般零售	|	450301	|	百货	|
|	450000	|	商业贸易	|	450300	|	一般零售	|	450302	|	超市	|
|	450000	|	商业贸易	|	450300	|	一般零售	|	450303	|	多业态零售	|
|	450000	|	商业贸易	|	450400	|	专业零售	|	450401	|	专业连锁	|
|	450000	|	商业贸易	|	450500	|	商业物业经营	|	450501	|	一般物业经营	|
|	450000	|	商业贸易	|	450500	|	商业物业经营	|	450502	|	专业市场	|
|	460000	|	休闲服务	|	460100	|	景点	|	460101	|	人工景点	|
|	460000	|	休闲服务	|	460100	|	景点	|	460102	|	自然景点	|
|	460000	|	休闲服务	|	460200	|	酒店	|	460201	|	酒店	|
|	460000	|	休闲服务	|	460300	|	旅游综合	|	460301	|	旅游综合	|
|	460000	|	休闲服务	|	460400	|	餐饮	|	460401	|	餐饮	|
|	460000	|	休闲服务	|	460500	|	其他休闲服务	|	460501	|	其他休闲服务	|
|	480000	|	银行	|	480100	|	银行	|	480101	|	银行	|
|	490000	|	非银金融	|	490100	|	证券	|	490101	|	证券	|
|	490000	|	非银金融	|	490200	|	保险	|	490201	|	保险	|
|	490000	|	非银金融	|	490300	|	多元金融	|	490301	|	多元金融	|
|	510000	|	综合	|	510100	|	综合	|	510101	|	综合	|
|	610000	|	建筑材料	|	610100	|	水泥制造	|	610101	|	水泥制造	|
|	610000	|	建筑材料	|	610200	|	玻璃制造	|	610201	|	玻璃制造	|
|	610000	|	建筑材料	|	610300	|	其他建材	|	610301	|	耐火材料	|
|	610000	|	建筑材料	|	610300	|	其他建材	|	610302	|	管材	|
|	610000	|	建筑材料	|	610300	|	其他建材	|	610303	|	其他建材	|
|	620000	|	建筑装饰	|	620100	|	房屋建设	|	620101	|	房屋建设	|
|	620000	|	建筑装饰	|	620200	|	装修装饰	|	620201	|	装修装饰	|
|	620000	|	建筑装饰	|	620300	|	基础建设	|	620301	|	城轨建设	|
|	620000	|	建筑装饰	|	620300	|	基础建设	|	620302	|	路桥施工	|
|	620000	|	建筑装饰	|	620300	|	基础建设	|	620303	|	水利工程	|
|	620000	|	建筑装饰	|	620300	|	基础建设	|	620304	|	铁路建设	|
|	620000	|	建筑装饰	|	620300	|	基础建设	|	620305	|	其他基础建设	|
|	620000	|	建筑装饰	|	620400	|	专业工程	|	620401	|	钢结构	|
|	620000	|	建筑装饰	|	620400	|	专业工程	|	620402	|	化学工程	|
|	620000	|	建筑装饰	|	620400	|	专业工程	|	620403	|	国际工程承包	|
|	620000	|	建筑装饰	|	620400	|	专业工程	|	620404	|	其他专业工程	|
|	620000	|	建筑装饰	|	620500	|	园林工程	|	620501	|	园林工程	|
|	630000	|	电气设备	|	630100	|	电机	|	630101	|	电机	|
|	630000	|	电气设备	|	630200	|	电气自动化设备	|	630201	|	电网自动化	|
|	630000	|	电气设备	|	630200	|	电气自动化设备	|	630202	|	工控自动化	|
|	630000	|	电气设备	|	630200	|	电气自动化设备	|	630203	|	计量仪表	|
|	630000	|	电气设备	|	630300	|	电源设备	|	630301	|	综合电力设备商	|
|	630000	|	电气设备	|	630300	|	电源设备	|	630302	|	风电设备	|
|	630000	|	电气设备	|	630300	|	电源设备	|	630303	|	光伏设备	|
|	630000	|	电气设备	|	630300	|	电源设备	|	630304	|	火电设备	|
|	630000	|	电气设备	|	630300	|	电源设备	|	630305	|	储能设备	|
|	630000	|	电气设备	|	630300	|	电源设备	|	630306	|	其它电源设备	|
|	630000	|	电气设备	|	630400	|	高低压设备	|	630401	|	高压设备	|
|	630000	|	电气设备	|	630400	|	高低压设备	|	630402	|	中压设备	|
|	630000	|	电气设备	|	630400	|	高低压设备	|	630403	|	低压设备	|
|	630000	|	电气设备	|	630400	|	高低压设备	|	630404	|	线缆部件及其他	|
|	640000	|	机械设备	|	640100	|	通用机械	|	640101	|	机床工具	|
|	640000	|	机械设备	|	640100	|	通用机械	|	640102	|	机械基础件	|
|	640000	|	机械设备	|	640100	|	通用机械	|	640103	|	磨具磨料	|
|	640000	|	机械设备	|	640100	|	通用机械	|	640104	|	内燃机	|
|	640000	|	机械设备	|	640100	|	通用机械	|	640105	|	制冷空调设备	|
|	640000	|	机械设备	|	640100	|	通用机械	|	640106	|	其它通用机械	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640201	|	工程机械	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640202	|	重型机械	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640203	|	冶金矿采化工设备	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640204	|	楼宇设备	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640205	|	环保设备	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640206	|	纺织服装设备	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640207	|	农用机械	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640208	|	印刷包装机械	|
|	640000	|	机械设备	|	640200	|	专用设备	|	640209	|	其它专用机械	|
|	640000	|	机械设备	|	640300	|	仪器仪表	|	640301	|	仪器仪表	|
|	640000	|	机械设备	|	640400	|	金属制品	|	640401	|	金属制品	|
|	640000	|	机械设备	|	640500	|	运输设备	|	640501	|	铁路设备	|
|	650000	|	国防军工	|	650100	|	航天装备	|	650101	|	航天装备	|
|	650000	|	国防军工	|	650200	|	航空装备	|	650201	|	航空装备	|
|	650000	|	国防军工	|	650300	|	地面兵装	|	650301	|	地面兵装	|
|	650000	|	国防军工	|	650400	|	船舶制造	|	650401	|	船舶制造	|
|	710000	|	计算机	|	710100	|	计算机设备	|	710101	|	计算机设备	|
|	710000	|	计算机	|	710200	|	计算机应用	|	710201	|	软件开发	|
|	710000	|	计算机	|	710200	|	计算机应用	|	710202	|	IT服务	|
|	720000	|	传媒	|	720100	|	文化传媒	|	720101	|	平面媒体	|
|	720000	|	传媒	|	720100	|	文化传媒	|	720102	|	影视动漫	|
|	720000	|	传媒	|	720100	|	文化传媒	|	720103	|	有线电视网络	|
|	720000	|	传媒	|	720100	|	文化传媒	|	720104	|	其他文化传媒	|
|	720000	|	传媒	|	720200	|	营销传播	|	720201	|	营销服务	|
|	720000	|	传媒	|	720300	|	互联网传媒	|	720301	|	互联网信息服务	|
|	720000	|	传媒	|	720300	|	互联网传媒	|	720302	|	移动互联网服务	|
|	720000	|	传媒	|	720300	|	互联网传媒	|	720303	|	其他互联网服务	|
|	730000	|	通信	|	730100	|	通信运营	|	730101	|	通信运营	|
|	730000	|	通信	|	730200	|	通信设备	|	730201	|	终端设备	|
|	730000	|	通信	|	730200	|	通信设备	|	730202	|	通信传输设备	|
|	730000	|	通信	|	730200	|	通信设备	|	730203	|	通信配套服务	|


